<?php

declare(strict_types=1);

namespace Drupal\Tests\Dashboard\Kernel;

use Drupal\dashboard\Entity\Dashboard;
use Drupal\KernelTests\KernelTestBase;
use Drupal\layout_builder\Section;

/**
 * Tests for dashboard config dependencies.
 *
 * @group dashboard
 */
class DashboardConfigDependenciesTest extends KernelTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = [
    'dashboard',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('dashboard');
  }

  /**
   * Tests dynamic permissions.
   */
  public function testCalculateDependencies() {
    $id = $this->randomMachineName();
    $label = $this->randomMachineName();
    /** @var \Drupal\dashboard\Entity\Dashboard $dashboard */
    $dashboard = Dashboard::create([
      'id' => $id,
      'label' => $label,
      'status' => TRUE,
      'weight' => 0,
    ]);
    $dashboard->save();

    // When layout builder isn't used, we don't depend on anything.
    $dependencies = $dashboard->calculateDependencies()->getDependencies();
    $this->assertEmpty($dependencies);

    // If we add a layout section, we depend on layout_builder module.
    $section = new Section('layout_id');
    $dashboard->appendSection($section);
    $dependencies = $dashboard->calculateDependencies()->getDependencies();

    $expected_dependencies = [
      'module' => [
        'layout_builder',
      ],
    ];
    $this->assertSame(array_keys($expected_dependencies), array_keys($dependencies));
    foreach ($expected_dependencies as $key => $expected_dependency) {
      $this->assertSame($expected_dependency, $dependencies[$key]);
    }
  }

}
